Learn R Programming

ivbma (version 1.05)

ivbma.sample.theta: Updates the IVBMA parameters

Description

Runs one step of the Gibbs Sampler in IVBMA

Usage

ivbma.sample.theta(theta,D,full)

Arguments

theta
a list containing all the parameters in the IVBMA model
D
dataset
full
Indicator of whether model averaging is performed (FALSE)

Value

Returns an updated theta object

References

Anna Karl and Alex Lenkoski (2012). "Instrumental Variable Bayesian Model Averaging via Conditional Bayes Factors" http://arxiv.org/abs/1202.5846

See Also

ivbma